@@ -1,4 +1,4 @@
-# $Id: getperlflags.pl,v 1.1 2005/07/19 19:22:12 ekalin Exp $
+# $Id: getperlflags.pl,v 1.2 2007/05/13 21:30:12 ekalin Exp $
 # The ExtUtils::Embed module returns, under Windows, compiler options
 # using the syntax used by Microsoft Compilers.
 # Since I compile KildClient for Windows with mingw32, a port of gcc and
@@ -29,10 +29,10 @@ sub kcldopts {
     $ldflags =~ /-libpath:"([^"]+)"/;
     my $libincdir = $1;
 
-    $ldflags =~ / ([A-Za-z0-9_\\:.]+)\b/;
-    my $libfile = $1;
+    #$ldflags =~ / ([A-Za-z0-9_\\:.]+)\b/;
+    #my $libfile = $1;
 
-    my $winldflags = "-L$libincdir $libfile";
+    my $winldflags = "-L$libincdir $libincdir/perl58.lib";
     $winldflags =~ s#\\#/#g;
 
     print $winldflags;
