@@ -1,4 +1,22 @@
-## $Id: kildclient.pl,v 1.37 2006/07/31 20:02:27 ekalin Exp $
+## $Id: kildclient.pl,v 1.41 2008/03/23 21:02:07 ekalin Exp $
+
+### Copyright (C) 2004-2008 Eduardo M Kalinowski <ekalin@gmail.com>
+###
+### This program is free software; you can redistribute it and/or modify
+### it under the terms of the GNU General Public License as published by
+### the Free Software Foundation; either version 2 of the License, or
+### (at your option) any later version.
+###
+### This program is distributed in the hope that it will be useful,
+### but WITHOUT ANY WARRANTY; without even the implied warranty of
+### MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+### GNU General Public License for more details.
+###
+### You should have received a copy of the GNU General Public License
+### along with this program; if not, write to the Free Software
+### Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+### MA 02110-1301, USA.
+
 ###
 ### kildclient.pl
 ###
@@ -68,7 +86,7 @@ sub _ { return gettext($_[0]); }
     my $pattern = shift;
 
     if (!$pattern) {
-      $self->echonl(sprintf(_("%s: Too few arguments."), "gag"));
+      $self->echonl(sprintf(_('%s: Too few arguments.'), 'gag'));
       return;
     }
 
@@ -93,7 +111,7 @@ sub _ { return gettext($_[0]); }
                                             0,
                                             $extrafirstarg);
         if (scalar @found == 0) {
-          $self->echonl(sprintf(_("No such %s"), $objname));
+          $self->echonl(sprintf(_('No such %s'), $objname));
         } else {
           foreach (@found) {
             if ($extrafirstarg) {
@@ -119,10 +137,10 @@ sub _ { return gettext($_[0]); }
 
     if (@_) {
       foreach (@_) {
-        $self->_listobject($_, "_listtrigger", 0, _("trigger"));
+        $self->_listobject($_, '_listtrigger', 0, _('trigger'));
       }
     } else {
-      $self->_listobject(undef,  "_listtrigger", 0, _("trigger"));
+      $self->_listobject(undef,  '_listtrigger', 0, _('trigger'));
     }
   }
 
@@ -132,10 +150,10 @@ sub _ { return gettext($_[0]); }
 
     if (@_) {
       foreach (@_) {
-        $self->_listobject($_, "_listalias", 1, _("alias"));
+        $self->_listobject($_, '_listalias', 1, _('alias'));
       }
     } else {
-      $self->_listobject(undef, "_listalias", 1, _("alias"));
+      $self->_listobject(undef, '_listalias', 1, _('alias'));
     }
   }
 
@@ -145,10 +163,10 @@ sub _ { return gettext($_[0]); }
 
     if (@_) {
       foreach (@_) {
-        $self->_listobject($_, "_listmacro", 2, _("macro"));
+        $self->_listobject($_, '_listmacro', 2, _('macro'));
       }
     } else {
-      $self->_listobject(undef, "_listmacro", 2, _("macro"));
+      $self->_listobject(undef, '_listmacro', 2, _('macro'));
     }
   }
 
@@ -158,10 +176,10 @@ sub _ { return gettext($_[0]); }
 
     if (@_) {
       foreach (@_) {
-        $self->_listobject($_, "_listtimer", 3, _("timer"));
+        $self->_listobject($_, '_listtimer', 3, _('timer'));
       }
     } else {
-      $self->_listobject(undef, "_listtimer", 3, _("timer"));
+      $self->_listobject(undef, '_listtimer', 3, _('timer'));
     }
   }
 
@@ -172,14 +190,105 @@ sub _ { return gettext($_[0]); }
 
     if (@_) {
       foreach (@_) {
-        $self->_listobject($_, "_listhook", 4, _("hook"), $event);
+        $self->_listobject($_, '_listhook', 4, _('hook'), $event);
       }
     } else {
-      $self->_listobject(undef, "_listhook", 4, _("hook"), $event);
+      $self->_listobject(undef, '_listhook', 4, _('hook'), $event);
     }
   }
 
 
+  sub gettriggernumber {
+    my $self = shift;
+
+    if (scalar @_ != 1) {
+      $self->echonl(sprintf(_('%s: Wrong number of arguments.'),
+                            'gettriggernumber'));
+      return undef;
+    }
+    my $name = shift;
+
+    my @found = $self->_getobjectnumber($name,
+                                        0,    # Trigger
+                                        0,    # By name
+                                        undef);
+    return @found;
+  }
+
+
+  sub getaliasnumber {
+    my $self = shift;
+
+    if (scalar @_ != 1) {
+      $self->echonl(sprintf(_('%s: Wrong number of arguments.'),
+                            'getaliasnumber'));
+      return undef;
+    }
+    my $name = shift;
+
+    my @found = $self->_getobjectnumber($name,
+                                        1,    # Alias
+                                        0,    # By name
+                                        undef);
+    return @found;
+  }
+
+
+  sub getmacronumber {
+    my $self = shift;
+
+    if (scalar @_ != 1) {
+      $self->echonl(sprintf(_('%s: Wrong number of arguments.'),
+                            'getmacronumber'));
+      return undef;
+    }
+    my $name = shift;
+
+    my @found = $self->_getobjectnumber($name,
+                                        2,    # Macro
+                                        0,    # By name
+                                        undef);
+    return @found;
+  }
+
+
+  sub gettimernumber {
+    my $self = shift;
+
+    if (scalar @_ != 1) {
+      $self->echonl(sprintf(_('%s: Wrong number of arguments.'),
+                            'gettimerrnumber'));
+      return undef;
+    }
+    my $name = shift;
+
+    my @found = $self->_getobjectnumber($name,
+                                        3,    # Timer
+                                        0,    # By name
+                                        undef);
+    return @found;
+  }
+
+
+  sub gethooknumber {
+    my $self = shift;
+
+    if (scalar @_ != 2) {
+      $self->echonl(sprintf(_('%s: Wrong number of arguments.'),
+                            'gethooknumber'));
+      return undef;
+    }
+    my $event = shift;
+    my $name  = shift;
+
+    my @found = $self->_getobjectnumber($name,
+                                        4,    # Timer
+                                        0,    # By name
+                                        $event);
+    return @found;
+  }
+
+
   sub _delobject {
     my $self    = shift;
     my ($target,
@@ -198,7 +307,7 @@ sub _ { return gettext($_[0]); }
           eval("\$deleted += \$self->_$function($target)");
         }
         if (!$deleted) {
-          $self->echonl(sprintf(_("No such %s"), $objname));
+          $self->echonl(sprintf(_('No such %s'), $objname));
         }
       } else {
         my @found = reverse($self->_getobjectnumber($target,
@@ -206,7 +315,7 @@ sub _ { return gettext($_[0]); }
                                                     0,
                                                     $extrafirstarg));
         if (scalar @found == 0) {
-          $self->echonl(sprintf(_("No such %s"), $objname));
+          $self->echonl(sprintf(_('No such %s'), $objname));
         } else {
           foreach (@found) {
             if ($extrafirstarg) {
@@ -220,44 +329,44 @@ sub _ { return gettext($_[0]); }
 
       unless ($self->{SILENT}) {
         if ($deleted == 1) {
-          $self->echonl(sprintf(_("1 %s deleted."), $objname));
+          $self->echonl(sprintf(_('1 %s deleted.'), $objname));
         } else {
-          $self->echonl(sprintf(_("%d %s deleted."), $deleted, $objnameplural));
+          $self->echonl(sprintf(_('%d %s deleted.'), $deleted, $objnameplural));
         }
       }
     } else {
-      $self->echonl(sprintf(_("%s: Too few arguments."), $function));
+      $self->echonl(sprintf(_('%s: Too few arguments.'), $function));
     }
   }
 
 
   sub deltrigger {
     my $self = shift;
-    $self->_delobject($_[0], "deltrigger", 0, _("trigger"), _("triggers"));
+    $self->_delobject($_[0], 'deltrigger', 0, _('trigger'), _('triggers'));
   }
 
 
   sub delalias {
     my $self = shift;
-    $self->_delobject($_[0], "delalias", 1, _("alias"), _("aliases"));
+    $self->_delobject($_[0], 'delalias', 1, _('alias'), _('aliases'));
   }
 
 
   sub delmacro {
     my $self = shift;
-    $self->_delobject($_[0], "delmacro", 2, _("macro"), _("macros"));
+    $self->_delobject($_[0], 'delmacro', 2, _('macro'), _('macros'));
   }
 
 
   sub deltimer {
     my $self = shift;
-    $self->_delobject($_[0], "deltimer", 3, _("timer"), _("timers"));
+    $self->_delobject($_[0], 'deltimer', 3, _('timer'), _('timers'));
   }
 
 
   sub delhook {
     my $self  = shift;
-    $self->_delobject($_[1], "delhook", 4, _("hook"), _("hooks"), $_[0]);
+    $self->_delobject($_[1], 'delhook', 4, _('hook'), _('hooks'), $_[0]);
   }
 
 
@@ -279,7 +388,7 @@ sub _ { return gettext($_[0]); }
           eval("\$ok = \$self->_$function($old, $new_pos)");
         }
         if (!$ok) {
-          $self->echonl(sprintf(_("No such %s."), $objname));
+          $self->echonl(sprintf(_('No such %s.'), $objname));
         }
       } else {
         my @found = $self->_getobjectnumber($old,
@@ -287,7 +396,7 @@ sub _ { return gettext($_[0]); }
                                             0,
                                             $extrafirstarg);
         if (scalar @found == 0) {
-          $self->echonl(sprintf(_("No such %s."), $objname));
+          $self->echonl(sprintf(_('No such %s.'), $objname));
         } else {
           if ($extrafirstarg) {
             eval("\$ok += \$self->_$function(\$extrafirstarg, $found[0], $new_pos)");
@@ -296,44 +405,44 @@ sub _ { return gettext($_[0]); }
           }
 
           unless ($self->{SILENT}) {
-            $self->echonl(sprintf(_("Successfully moved %s."), $objname));
+            $self->echonl(sprintf(_('Successfully moved %s.'), $objname));
           }
         }
       }
     } else {
-      $self->echonl(sprintf(_("%s: Too few arguments."), $function));
+      $self->echonl(sprintf(_('%s: Too few arguments.'), $function));
     }
   }
 
 
   sub movetrigger {
     my $self = shift;
-    $self->_moveobject($_[0], $_[1], "movetrigger", 0, _("trigger"));
+    $self->_moveobject($_[0], $_[1], 'movetrigger', 0, _('trigger'));
   }
 
 
   sub movealias {
     my $self = shift;
-    $self->_moveobject($_[0], $_[1], "movealias", 1, _("alias"));
+    $self->_moveobject($_[0], $_[1], 'movealias', 1, _('alias'));
   }
 
 
   sub movemacro {
     my $self = shift;
-    $self->_moveobject($_[0], $_[1], "movemacro", 2, _("macro"));
+    $self->_moveobject($_[0], $_[1], 'movemacro', 2, _('macro'));
   }
 
 
   sub movetimer {
     my $self = shift;
-    $self->_moveobject($_[0], $_[1], "movetimer", 3, _("timer"));
+    $self->_moveobject($_[0], $_[1], 'movetimer', 3, _('timer'));
   }
 
 
   sub movehook {
     my $self  = shift;
     my $event = shift;
-    $self->_moveobject($_[0], $_[1], "movehook", 4, _("hook"), $event);
+    $self->_moveobject($_[0], $_[1], 'movehook', 4, _('hook'), $event);
   }
 
 
@@ -357,7 +466,7 @@ sub _ { return gettext($_[0]); }
                                           0,
                                           $extrafirstarg);
       if (scalar @found == 0) {
-        $self->echonl(sprintf(_("No such %s"), _($function)));
+        $self->echonl(sprintf(_('No such %s'), _($function)));
       } else {
         foreach (@found) {
           if ($extrafirstarg) {
@@ -376,10 +485,10 @@ sub _ { return gettext($_[0]); }
 
     if (@_) {
       foreach (@_) {
-        $self->_enadisobject($_, 1, "trigger", 0);
+        $self->_enadisobject($_, 1, 'trigger', 0);
       }
     } else {
-      $self->echonl(sprintf(_("%s: Too few arguments."), "enatrigger"));
+      $self->echonl(sprintf(_('%s: Too few arguments.'), 'enatrigger'));
     }
   }
 
@@ -389,10 +498,10 @@ sub _ { return gettext($_[0]); }
 
     if (@_) {
       foreach (@_) {
-        $self->_enadisobject($_, 0, "trigger", 0);
+        $self->_enadisobject($_, 0, 'trigger', 0);
       }
     } else {
-      $self->echonl(sprintf(_("%s: Too few arguments."), "distrigger"));
+      $self->echonl(sprintf(_('%s: Too few arguments.'), 'distrigger'));
     }
   }
 
@@ -402,10 +511,10 @@ sub _ { return gettext($_[0]); }
 
     if (@_) {
       foreach (@_) {
-        $self->_enadisobject($_, 1, "alias", 1);
+        $self->_enadisobject($_, 1, 'alias', 1);
       }
     } else {
-      $self->echonl(sprintf(_("%s: Too few arguments."), "enaalias"));
+      $self->echonl(sprintf(_('%s: Too few arguments.'), 'enaalias'));
     }
   }
 
@@ -415,10 +524,10 @@ sub _ { return gettext($_[0]); }
 
     if (@_) {
       foreach (@_) {
-        $self->_enadisobject($_, 0, "alias", 1);
+        $self->_enadisobject($_, 0, 'alias', 1);
       }
     } else {
-      $self->echonl(sprintf(_("%s: Too few arguments."), "disalias"));
+      $self->echonl(sprintf(_('%s: Too few arguments.'), 'disalias'));
     }
   }
 
@@ -428,10 +537,10 @@ sub _ { return gettext($_[0]); }
 
     if (@_) {
       foreach (@_) {
-        $self->_enadisobject($_, 1, "macro", 2);
+        $self->_enadisobject($_, 1, 'macro', 2);
       }
     } else {
-      $self->echonl(sprintf(_("%s: Too few arguments."), "enamacro"));
+      $self->echonl(sprintf(_('%s: Too few arguments.'), 'enamacro'));
     }
   }
 
@@ -441,10 +550,10 @@ sub _ { return gettext($_[0]); }
 
     if (@_) {
       foreach (@_) {
-        $self->_enadisobject($_, 0, "macro", 2);
+        $self->_enadisobject($_, 0, 'macro', 2);
       }
     } else {
-      $self->echonl(sprintf(_("%s: Too few arguments."), "dismacro"));
+      $self->echonl(sprintf(_('%s: Too few arguments.'), 'dismacro'));
     }
   }
 
@@ -454,10 +563,10 @@ sub _ { return gettext($_[0]); }
 
     if (@_) {
       foreach (@_) {
-        $self->_enadisobject($_, 1, "timer", 3);
+        $self->_enadisobject($_, 1, 'timer', 3);
       }
     } else {
-      $self->echonl(sprintf(_("%s: Too few arguments."), "enatimer"));
+      $self->echonl(sprintf(_('%s: Too few arguments.'), 'enatimer'));
     }
   }
 
@@ -467,10 +576,10 @@ sub _ { return gettext($_[0]); }
 
     if (@_) {
       foreach (@_) {
-        $self->_enadisobject($_, 0, "timer", 3);
+        $self->_enadisobject($_, 0, 'timer', 3);
       }
     } else {
-      $self->echonl(sprintf(_("%s: Too few arguments."), "distimer"));
+      $self->echonl(sprintf(_('%s: Too few arguments.'), 'distimer'));
     }
   }
 
@@ -481,10 +590,10 @@ sub _ { return gettext($_[0]); }
 
     if (@_) {
       foreach (@_) {
-        $self->_enadisobject($_, 1, "hook", 4, $event);
+        $self->_enadisobject($_, 1, 'hook', 4, $event);
       }
     } else {
-      $self->echonl(sprintf(_("%s: Too few arguments."), "enahook"));
+      $self->echonl(sprintf(_('%s: Too few arguments.'), 'enahook'));
     }
   }
 
@@ -495,10 +604,10 @@ sub _ { return gettext($_[0]); }
 
     if (@_) {
       foreach (@_) {
-        $self->_enadisobject($_, 0, "hook", 4, $event);
+        $self->_enadisobject($_, 0, 'hook', 4, $event);
       }
     } else {
-      $self->echonl(sprintf(_("%s: Too few arguments."), "dishook"));
+      $self->echonl(sprintf(_('%s: Too few arguments.'), 'dishook'));
     }
   }
 
@@ -508,10 +617,10 @@ sub _ { return gettext($_[0]); }
     my $trigger = shift;
 
     if (!defined($trigger)) {
-      $self->echonl(sprintf(_("%s: Too few arguments."), "triggerenabled"));
+      $self->echonl(sprintf(_('%s: Too few arguments.'), 'triggerenabled'));
       return undef;
     }
-    return $self->_objectenabled($trigger, 0, _("trigger"));
+    return $self->_objectenabled($trigger, 0, _('trigger'));
   }
 
 
@@ -520,10 +629,10 @@ sub _ { return gettext($_[0]); }
     my $alias = shift;
 
     if (!defined($alias)) {
-      $self->echonl(sprintf(_("%s: Too few arguments."), "aliasenabled"));
+      $self->echonl(sprintf(_('%s: Too few arguments.'), 'aliasenabled'));
       return undef;
     }
-    return $self->_objectenabled($alias, 1, _("alias"));
+    return $self->_objectenabled($alias, 1, _('alias'));
   }
 
 
@@ -532,10 +641,10 @@ sub _ { return gettext($_[0]); }
     my $macro = shift;
 
     if (!defined($macro)) {
-      $self->echonl(sprintf(_("%s: Too few arguments."), "macroenabled"));
+      $self->echonl(sprintf(_('%s: Too few arguments.'), 'macroenabled'));
       return undef;
     }
-    return $self->_objectenabled($macro, 2, _("macro"));
+    return $self->_objectenabled($macro, 2, _('macro'));
   }
 
 
@@ -544,10 +653,10 @@ sub _ { return gettext($_[0]); }
     my $timer = shift;
 
     if (!defined($timer)) {
-      $self->echonl(sprintf(_("%s: Too few arguments."), "timerenabled"));
+      $self->echonl(sprintf(_('%s: Too few arguments.'), 'timerenabled'));
       return undef;
     }
-    return $self->_objectenabled($timer, 3, _("timer"));
+    return $self->_objectenabled($timer, 3, _('timer'));
   }
 
 
@@ -557,10 +666,10 @@ sub _ { return gettext($_[0]); }
     my $hook  = shift;
 
     if (!$event || !defined($hook)) {
-      $self->echonl(sprintf(_("%s: Too few arguments."), "hookenabled"));
+      $self->echonl(sprintf(_('%s: Too few arguments.'), 'hookenabled'));
       return undef;
     }
-    return $self->_objectenabled($hook, 4, _("hook"), $event);
+    return $self->_objectenabled($hook, 4, _('hook'), $event);
   }
 
 
@@ -588,7 +697,7 @@ sub _ { return gettext($_[0]); }
     my $file = shift;
 
     unless (open(PLUGIN, "<$file")) {
-      return _("Could not open file.");
+      return _('Could not open file.');
     }
 
     my $nameline   = <PLUGIN>;
@@ -618,14 +727,14 @@ sub _ { return gettext($_[0]); }
       $desc = $1;
     }
     if ($authorline !~ /^#: Author: (.*)$/) {
-      $author = _("Unknown");
+      $author = _('Unknown');
     } else {
       $author = $1;
     }
     CORE::close(PLUGIN);
 
     if ($fail) {
-      return _("Invalid plugin file.");
+      return _('Invalid plugin file.');
     } else {
       return (undef, $name, $vers, $desc, $author);
     }
@@ -656,9 +765,9 @@ sub _ { return gettext($_[0]); }
     my $prevversion = $self->getpluginversion($name);
     if ($prevversion) {
       if ($prevversion eq $vers) {
-        return _("Plugin already loaded. Try enabling it.");
+        return _('Plugin already loaded. Try enabling it.');
       } else {
-        return sprintf(_("Version %s of this plugin is already loaded."),
+        return sprintf(_('Version %s of this plugin is already loaded.'),
                        $prevversion);
       }
     }
@@ -668,10 +777,10 @@ sub _ { return gettext($_[0]); }
 
     if ($@) {
       $self->_stopplugin(0);
-      return sprintf(_("Error in plugin file: %s"), $@);
+      return sprintf(_('Error in plugin file: %s'), $@);
     } else {
       $self->_stopplugin(1);
-      return undef;
+      return (undef, $name);
     }
   }
 
@@ -680,22 +789,22 @@ sub _ { return gettext($_[0]); }
     my $self = shift;
 
     if ($self->{WORLDPTR} != $::world->{WORLDPTR}) {
-      $::world->echonl(_("Cannot load a plugin in another world."));
+      $::world->echonl(_('Cannot load a plugin in another world.'));
       return 0;
     }
 
     unless (defined($_[0])) {
-      $self->echonl(_("Plugin not specified"));
+      $self->echonl(_('Plugin not specified'));
       return 0;
     }
 
-    my $error = $self->_loadplugin($_[0]);
+    my ($error, $name) = $self->_loadplugin($_[0]);
     if ($error) {
       $self->echonl($error);
-      $self->echonl(_("Plugin not loaded."));
+      $self->echonl(_('Plugin not loaded.'));
       return 0;
     } else {
-      $self->echonl(_("Plugin loaded."));
+      $self->echonl(sprintf(_("Plugin '%s' loaded."), $name));
       return 1;
     }
   }
@@ -705,13 +814,13 @@ sub _ { return gettext($_[0]); }
     my $self = shift;
     my $plugin = $_[0];
 
-    die _("Plugin not specified") unless defined($plugin);
+    die _('Plugin not specified') unless defined($plugin);
 
     my $prevversion = $self->getpluginversion($plugin);
     return 1 if ($prevversion); # This plugin is already loaded
 
-    my $error = $self->_loadplugin($plugin);
-    die sprintf(_("Could not load plugin %s"), $plugin) if ($error);
+    my ($error, $dummy) = $self->_loadplugin($plugin);
+    die sprintf(_('Could not load plugin %s'), $plugin) if ($error);
 
     return 1;
   }
@@ -723,7 +832,7 @@ sub _ { return gettext($_[0]); }
 
     my $pluginver = $self->getpluginversion($pluginname);
     unless ($pluginver) {
-      $self->echonl(_("Plugin not loaded."));
+      $self->echonl(_('Plugin not loaded.'));
       return 0;
     }
 
@@ -773,7 +882,7 @@ sub _ { return gettext($_[0]); }
     $self->{SILENT} = 1;
 
     if (!$pluginname) {
-      $self->echonl(sprintf(_("%s: Too few arguments."), "enaplugin"));
+      $self->echonl(sprintf(_('%s: Too few arguments.'), 'enaplugin'));
       return;
     }
 
@@ -787,7 +896,7 @@ sub _ { return gettext($_[0]); }
     if ($@) {
       if ($self->_enadisplugin($pluginname, 1)) {
         unless ($prevstate) {
-          $self->echonl(_("Plugin enabled."));
+          $self->echonl(_('Plugin enabled.'));
         }
         $self->_markpluginenadis($pluginname, 1);
       }
@@ -806,7 +915,7 @@ sub _ { return gettext($_[0]); }
     $self->{SILENT} = 1;
 
     if (!$pluginname) {
-      $self->echonl(sprintf(_("%s: Too few arguments."), "displugin"));
+      $self->echonl(sprintf(_('%s: Too few arguments.'), 'displugin'));
       return;
     }
 
@@ -820,7 +929,7 @@ sub _ { return gettext($_[0]); }
     if ($@) {
       if ($self->_enadisplugin($pluginname, 0)) {
         unless ($prevstate) {
-          $self->echonl(_("Plugin disabled."));
+          $self->echonl(_('Plugin disabled.'));
         }
         $self->_markpluginenadis($pluginname, 0);
       }
@@ -894,16 +1003,16 @@ sub colorize {
 
   $str =~ s{(&|\^)([0-5])([0-5])([0-5])X}
            {"\e[" .
-            ($1 eq '&' ? "38" : "48") .
+            ($1 eq '&' ? '38' : '48') .
             ";5;" .
             (($2*36 + $3*6 + $4) + 16) .
             "m"}eg;
   $str =~ s{(&|\^)([0-9]|[01][0-9]|2[0-3])G}
            {"\e[" .
-            ($1 eq '&' ? "38" : "48") .
-            ";5;" .
+            ($1 eq '&' ? '38' : '48') .
+            ';5;' .
             ($2 + 232) .
-            "m"}eg;
+            'm'}eg;
 
   foreach my $i (keys %colorsubst) {
     $str =~ s/$i/$colorsubst{$i}/g;
@@ -921,7 +1030,7 @@ sub stripcolorize {
   my $string = shift;
 
   if (!$string) {
-    return "";
+    return '';
   }
 
   $string =~ s/(&|^)[dxrgObpcwzRGYBPCW]//g;
@@ -946,14 +1055,14 @@ sub path {
 
     $path = substr($path, $+[0]);
 
-    $num = 1 if ($num eq "");
+    $num = 1 if ($num eq '');
     $cmd =~ s/\{(.+)\}/$1/;
 
     my $i;
     for ($i = 0; $i < $num; ++$i) {
       $::world->send("$cmd");
     }
-  } until ($path eq "");
+  } until ($path eq '');
 }
 
 
@@ -964,10 +1073,10 @@ sub __sethelpfile {
 
 sub help {
   if (!defined($_[0])) {
-    $_[0] = "index";
+    $_[0] = 'index';
   }
 
-  open(HFILE, "<$__helpfile") or die(_("Cannot open help file."));
+  open(HFILE, "<$__helpfile") or die(_('Cannot open help file.'));
 
   my $outputting = 0;
   while (<HFILE>) {
@@ -985,5 +1094,20 @@ sub help {
     }
   }
 
-  $::world->echonl(_("Help topic not found."));
+  $::world->echonl(_('Help topic not found.'));
 }
+
+
+### Deprecated functions
+sub getwindowsize {
+  $::world->echonl(_('Warning: the getwindowsize() function is deprecated and will be removed.'));
+  $::world->echonl(_('Use $window->getsize() instead.'));
+  $::window->getsize();
+}
+
+sub minimize {
+  $::world->echonl(_('Warning: the minimize() function is deprecated and will be removed.'));
+  $::world->echonl(_('Use $window->minimize() instead.'));
+  $::window->minimize();
+}
+
