@@ -1,6 +1,8 @@
-/* $Id: main.c,v 1.49 2007/11/25 18:19:36 ekalin Exp $ */
+/* $Id: main.c,v 1.52 2008/05/03 13:13:53 ekalin Exp $ */
 
 /*
+ * Copyright (C) 2004-2008 Eduardo M Kalinowski <ekalin@gmail.com>
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -13,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
- * MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -153,7 +155,9 @@ main(int argc, char *argv[], char *env[])
   }
 #endif
 
-  g_thread_init(NULL);
+  if (!g_thread_supported()) {
+    g_thread_init(NULL);
+  }
   gtk_init(&argc, &argv);
   gtk_rc_parse_string("gtk-entry-select-on-focus=0");
 
