@@ -1,6 +1,8 @@
-/* $Id: mainwindow.c,v 1.130 2007/11/18 20:10:39 ekalin Exp $ */
+/* $Id: mainwindow.c,v 1.136 2008/04/05 13:38:17 ekalin Exp $ */
 
 /*
+ * Copyright (C) 2004-2008 Eduardo M Kalinowski <ekalin@gmail.com>
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -13,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
- * MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -69,6 +71,9 @@ static GtkWidget *ntbkWorlds;
  * Function prototypes *
  ***********************/
 static gboolean update_world_with_focus(gpointer data);
+static void     about_dlg_url_hook(GtkAboutDialog *about,
+                                   const gchar    *link,
+                                   gpointer        data);
 static gint     attach_world_gui(WorldGUI *gui);
 static void     detach_world_gui(WorldGUI *gui);
 static gchar   *format_time_string(World *world, int ctime, int itime);
@@ -254,15 +259,15 @@ window_focus_in_cb(GtkWidget     *widget,
                                  currentWorld->selection_end);
   }
 
-  if (currentWorld->connected) {
-    execute_hook(currentWorld, "OnGetFocus", NULL);
-  }
-
-  gtk_window_set_title(GTK_WINDOW(wndMain), "KildClient");
+  window_has_focus = TRUE;
+  adjust_window_title();
   if (globalPrefs.urgency_hint) {
     gtk_window_set_urgency_hint(GTK_WINDOW(wndMain), FALSE);
   }
-  window_has_focus = TRUE;
+
+  if (currentWorld->connected) {
+    execute_hook(currentWorld, "OnGetFocus", NULL);
+  }
 
   return FALSE;
 }
@@ -282,13 +287,13 @@ window_focus_out_cb(GtkWidget     *widget,
                                       &currentWorld->selection_start,
                                       &currentWorld->selection_end);
 
+  window_has_focus = FALSE;
+  adjust_window_title();
+
   if (currentWorld->connected) {
     execute_hook(currentWorld, "OnLoseFocus", NULL);
   }
 
-  window_has_focus = FALSE;
-  adjust_window_title();
-
   return FALSE;
 }
 
@@ -296,20 +301,36 @@ window_focus_out_cb(GtkWidget     *widget,
 void
 adjust_window_title(void)
 {
-  if (worlds_with_new_text == 0) {
-    gtk_window_set_title(GTK_WINDOW(wndMain), "KildClient");
-  } else if (worlds_with_new_text == 1) {
-    gtk_window_set_title(GTK_WINDOW(wndMain), "(*) KildClient");
+  gchar *worldname;
+  gchar *title;
+
+  if (currentWorld) {
+    if (currentWorld->connected) {
+      worldname = g_strdup_printf(" - %s", currentWorld->name);
+    } else {
+      worldname = g_strdup_printf(" - [%s]", currentWorld->name);
+    }
   } else {
-    gchar *title;
-    title = g_strdup_printf("(*)[%d] KildClient",
-                            worlds_with_new_text);
-    gtk_window_set_title(GTK_WINDOW(wndMain), title);
-    g_free(title);
+    worldname = g_strdup("");
   }
 
-  if (globalPrefs.urgency_hint) {
-    gtk_window_set_urgency_hint(GTK_WINDOW(wndMain), worlds_with_new_text);
+  if (window_has_focus || worlds_with_new_text == 0) {
+    title = g_strdup_printf("KildClient%s", worldname);
+  } else if (worlds_with_new_text == 1) {
+    title = g_strdup_printf("(*) KildClient%s", worldname);
+  } else {
+    title = g_strdup_printf("(*)[%d] KildClient%s",
+                            worlds_with_new_text, worldname);
+  }
+
+  gtk_window_set_title(GTK_WINDOW(wndMain), title);
+  g_free(worldname);
+  g_free(title);
+
+  if (!window_has_focus) {
+    if (globalPrefs.urgency_hint) {
+      gtk_window_set_urgency_hint(GTK_WINDOW(wndMain), worlds_with_new_text);
+    }
   }
 }
 
@@ -391,6 +412,8 @@ update_world_with_focus(gpointer data)
 
     PERL_SET_CONTEXT(currentWorld->perl_interpreter);
 
+    adjust_window_title();
+
     if (currentWorld->connected) {
       execute_hook(currentWorld, "OnGetFocus", NULL);
     }
@@ -751,6 +774,8 @@ about_menu_cb(GtkWidget *widget, gpointer data)
   static GtkWidget *dlgAbout = NULL;
 
   if (!dlgAbout) {
+    gtk_about_dialog_set_url_hook(about_dlg_url_hook, NULL, NULL);
+
     xml = glade_xml_new(get_kildclient_installed_file("kildclient.glade"),
                         "dlgAbout", NULL);
     dlgAbout = glade_xml_get_widget(xml, "dlgAbout");
@@ -764,6 +789,16 @@ about_menu_cb(GtkWidget *widget, gpointer data)
 }
 
 
+static
+void
+about_dlg_url_hook(GtkAboutDialog *about, const gchar *link, gpointer data)
+{
+  gchar *url = g_strdup(link);
+  menu_url_open(GTK_WIDGET(about), url);
+}
+
+
+
 static
 gint
 attach_world_gui(WorldGUI *gui)
