@@ -1,6 +1,8 @@
-/* $Id: net.c,v 1.103 2007/11/25 18:19:36 ekalin Exp $ */
+/* $Id: net.c,v 1.107 2008/03/23 21:09:37 ekalin Exp $ */
 
 /*
+ * Copyright (C) 2004-2008 Eduardo M Kalinowski <ekalin@gmail.com>
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -13,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
- * MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -205,12 +207,12 @@ connect_to(World *world, gchar **errmsg)
   world_for_perl = world;
   if (!world->connected_at_least_once) {
     init_perl_script(world);
+    load_permanent_variables(world);
     load_startup_plugins(world);
     if (world->scriptfile) {
       perl_script_import_file(world->perl_interpreter, world->scriptfile);
     }
     load_command_history(world);
-    load_permanent_variables(world);
   } else {
     if (world->has_unread_text) {
       world->has_unread_text = 0;
@@ -524,6 +526,11 @@ connected_to(World *world)
   }
 #endif
 
+  world->connected         = TRUE;
+  world->connecting        = FALSE;
+  world->connected_time    = time(NULL);
+  world->last_command_time = time(NULL);
+
   status_text = g_strdup_printf(_("Connected%s to host %s (%s) port %s."),
                                 world->use_tls ? _(" with SSL") : "",
                                 world->host, world->host_ip, world->port);
@@ -532,6 +539,7 @@ connected_to(World *world)
   ansitextview_append_string(world->gui, "\n");
   gtk_label_set_text(world->gui->lblStatus, status_text);
   g_free(status_text);
+  adjust_window_title();
 
   perform_auto_logon(world);
   execute_hook(world, "OnConnect", NULL);
@@ -549,11 +557,6 @@ connected_to(World *world)
     }
   }
 
-  world->connected         = TRUE;
-  world->connecting        = FALSE;
-  world->connected_time    = time(NULL);
-  world->last_command_time = time(NULL);
-
   /* We now read the socket */
   g_source_remove(world->io_watch_id);
   world->io_watch_id = g_io_add_watch_full(world->iochan,
