@@ -1,6 +1,8 @@
-/* $Id: perlscript.c,v 1.123 2007/11/24 19:14:36 ekalin Exp $ */
+/* $Id: perlscript.c,v 1.128 2008/03/23 21:09:36 ekalin Exp $ */
 
 /*
+ * Copyright (C) 2004-2008 Eduardo M Kalinowski <ekalin@gmail.com>
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -13,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
- * MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -56,6 +58,7 @@
  * Function prototypes *
  ***********************/
 static SV     *create_world_var(World *world);
+static SV     *create_window_var(void);
 static World  *fetch_world(int items, SV *self_ref, HV **self_to_store);
 static void    xs_init();
 static int     world_name_comparer(const World *world, const char *name);
@@ -101,6 +104,8 @@ init_perl_script(World *world)
 
   SV *world_ref;
   SV *world_var;
+  SV *window_ref;
+  SV *window_var;
 
   my_argv = g_malloc(sizeof(char *) * (my_argc_static + 2));
   for (i = 0; i < my_argc_static; ++i) {
@@ -140,10 +145,14 @@ init_perl_script(World *world)
 
   /* Create $world variable */
   world_ref = create_world_var(world);
-
   world_var = get_sv("world", TRUE);
   sv_setsv(world_var, world_ref);
 
+  /* Create $window variable */
+  window_ref = create_window_var();
+  window_var = get_sv("window", TRUE);
+  sv_setsv(window_var, window_ref);
+
   g_free(my_argv[i]);
   g_free(my_argv[i+1]);
   g_free(my_argv);
@@ -155,6 +164,8 @@ static
 SV *
 create_world_var(World *world)
 {
+  /* Currently the hash holds nothing. It's just used to indicate that
+     the function refers to the window. */
   HV *world_hash;
   IV  worldptriv;
   SV *worldptrsv;
@@ -175,6 +186,24 @@ create_world_var(World *world)
 }
 
 
+static
+SV *
+create_window_var(void)
+{
+  HV *window_hash;
+  SV *window_ref;
+  HV *window_pkg_stash;
+
+  window_hash = newHV();
+
+  window_ref = newRV_noinc((SV *) window_hash);
+  window_pkg_stash = gv_stashpv("Window", TRUE);
+  window_ref = sv_bless(window_ref, window_pkg_stash);
+
+  return window_ref;
+}
+
+
 void
 destruct_perl_script(PerlInterpreter *perl_interpreter)
 {
@@ -492,7 +521,7 @@ XS_connectother(pTHX_ CV *perlcv)
 
 static
 void
-XS_minimize(pTHX_ CV *perlcv)
+XS_window_minimize(pTHX_ CV *perlcv)
 {
   dMARK;
   dAX;
@@ -505,7 +534,7 @@ XS_minimize(pTHX_ CV *perlcv)
 
 static
 void
-XS_getwindowsize(pTHX_ CV *perlcv)
+XS_window_getsize(pTHX_ CV *perlcv)
 {
   guint cols  = 0;
   guint lines = 0;
@@ -520,6 +549,42 @@ XS_getwindowsize(pTHX_ CV *perlcv)
 }
 
 
+static
+void
+XS_window_settitle(pTHX_ CV *perlcv)
+{
+  dXSARGS;
+
+  if (items == 1) {
+    warn(_("%s: Too few arguments"), "settitle");
+    XSRETURN_EMPTY;
+  }
+
+  gtk_window_set_title(GTK_WINDOW(wndMain), SvPV_nolen(ST(1)));
+
+  XSRETURN_EMPTY;
+}
+
+
+static
+void
+XS_window_seturgencyhint(pTHX_ CV *perlcv)
+{
+  dXSARGS;
+
+  if (items == 1) {
+    warn(_("%s: Too few arguments"), "seturgencyhint");
+    XSRETURN_EMPTY;
+  }
+
+  if (globalPrefs.urgency_hint) {
+    gtk_window_set_urgency_hint(GTK_WINDOW(wndMain), SvIV(ST(1)));
+  }
+
+  XSRETURN_EMPTY;
+}
+
+
 static
 void
 XS_next(pTHX_ CV *perlcv)
@@ -2749,6 +2814,24 @@ XS_logfile(pTHX_ CV *perlcv)
 }
 
 
+static
+void
+XS_getlogfile(pTHX_ CV *perlcv)
+{
+  FETCHWORLDVARS;
+  dXSARGS;
+
+  FETCHWORLD;
+
+  if (world->log_file) {
+    XST_mPV(0, world->log_actual_file);
+    XSRETURN(1);
+  } else {
+    XSRETURN_UNDEF;
+  }
+}
+
+
 static
 void
 XS__writetolog(pTHX_ CV *perlcv)
@@ -3052,10 +3135,13 @@ xs_init()
 
 
   /* Our subroutines */
-  newXS("getversion",    XS_getversion,    "");
-  newXS("quit",          XS_quit,          "");
-  newXS("minimize",      XS_minimize,      "");
-  newXS("getwindowsize", XS_getwindowsize, "");
+  newXS("getversion",       XS_getversion, "");
+  newXS("quit",             XS_quit,       "");
+
+  newXS("Window::minimize",       XS_window_minimize,       "Window");
+  newXS("Window::getsize",        XS_window_getsize,        "Window");
+  newXS("Window::settitle",       XS_window_settitle,       "Window");
+  newXS("Window::seturgencyhint", XS_window_seturgencyhint, "Window");
 
   newXS("World::dc",           XS_dc,           "World");
   newXS("World::reconnect",    XS_reconnect,    "World");
@@ -3118,6 +3204,7 @@ xs_init()
   newXS("World::_movehook", XS__movehook, "World");
 
   newXS("World::logfile",     XS_logfile,     "World");
+  newXS("World::getlogfile",  XS_getlogfile,  "World");
   newXS("World::_writetolog", XS__writetolog, "World");
 
   newXS("World::listplugin",        XS_listplugin,        "World");
