@@ -1,6 +1,8 @@
-/* $Id: worldselector.c,v 1.55 2007/11/25 18:37:05 ekalin Exp $ */
+/* $Id: worldselector.c,v 1.58 2008/05/03 13:34:08 ekalin Exp $ */
 
 /*
+ * Copyright (C) 2004-2008 Eduardo M Kalinowski <ekalin@gmail.com>
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -13,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
- * MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -192,13 +194,13 @@ create_world_selector_dlg(GtkWindow* parent)
                                                | GTK_DIALOG_DESTROY_WITH_PARENT
                                                | GTK_DIALOG_NO_SEPARATOR,
                                                GTK_STOCK_CANCEL, GTK_RESPONSE_CLOSE,
-                                               _("_Connect"), GTK_RESPONSE_OK,
+                                               _("C_onnect"), GTK_RESPONSE_OK,
                                                NULL);
   gtk_dialog_set_default_response(GTK_DIALOG(dlgSelectWorld), GTK_RESPONSE_OK);
   gtk_container_set_border_width(GTK_CONTAINER(dlgSelectWorld), 8);
 
-  radFromList = gtk_radio_button_new_with_label(NULL,
-                                                _("Select a saved world:"));
+  radFromList = gtk_radio_button_new_with_mnemonic(NULL,
+                                                   _("_Select a saved world:"));
   gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dlgSelectWorld)->vbox),
                      radFromList,
                      FALSE, FALSE, 4);
@@ -249,7 +251,7 @@ create_world_selector_dlg(GtkWindow* parent)
                    G_CALLBACK(add_edit_buttons_cb), GINT_TO_POINTER(0));
   gtk_box_pack_start(GTK_BOX(btnbox), btnNew, TRUE, TRUE, 0);
 
-  btnEdit = gtk_button_new_with_label(_("Edit"));
+  btnEdit = gtk_button_new_with_mnemonic(_("_Edit"));
   g_signal_connect(G_OBJECT(btnEdit), "clicked",
                    G_CALLBACK(add_edit_buttons_cb), GINT_TO_POINTER(1));
   gtk_box_pack_start(GTK_BOX(btnbox), btnEdit, TRUE, TRUE, 0);
@@ -266,15 +268,15 @@ create_world_selector_dlg(GtkWindow* parent)
   gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dlgSelectWorld)->vbox),
                      gtk_hseparator_new(), TRUE, TRUE, 8);
   radManually =
-    gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(radFromList),
-                                                _("Or connect directly:"));
+    gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(radFromList),
+                                                   _("Or connect d_irectly:"));
   gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dlgSelectWorld)->vbox),
                      radManually,
                      FALSE, FALSE, 4);
 
   table = gtk_table_new(2, 2, FALSE);
 
-  lblHost = gtk_label_new(_("Host:"));
+  lblHost = gtk_label_new_with_mnemonic(_("_Host:"));
   gtk_table_attach(GTK_TABLE(table), lblHost,
                    0, 1, 0, 1,
                    GTK_EXPAND | GTK_SHRINK | GTK_FILL,
@@ -282,6 +284,7 @@ create_world_selector_dlg(GtkWindow* parent)
                    4, 4);
 
   txtHost = gtk_entry_new();
+  gtk_label_set_mnemonic_widget(GTK_LABEL(lblHost), txtHost);
   gtk_entry_set_activates_default(GTK_ENTRY(txtHost), TRUE);
   g_signal_connect(G_OBJECT(txtHost), "changed",
                    G_CALLBACK(set_manually_cb), NULL);
@@ -291,7 +294,7 @@ create_world_selector_dlg(GtkWindow* parent)
                    GTK_EXPAND | GTK_SHRINK | GTK_FILL,
                    4, 4);
 
-  lblPort = gtk_label_new(_("Port:"));
+  lblPort = gtk_label_new_with_mnemonic(_("_Port:"));
   gtk_table_attach(GTK_TABLE(table), lblPort,
                    0, 1, 1, 2,
                    GTK_EXPAND | GTK_SHRINK | GTK_FILL,
@@ -299,6 +302,7 @@ create_world_selector_dlg(GtkWindow* parent)
                    4, 4);
 
   txtPort = gtk_entry_new();
+  gtk_label_set_mnemonic_widget(GTK_LABEL(lblPort), txtPort);
   gtk_entry_set_activates_default(GTK_ENTRY(txtPort), TRUE);
   g_signal_connect(G_OBJECT(txtPort), "changed",
                    G_CALLBACK(set_manually_cb), NULL);
